import http from './http.js'

let limit = {}
let debounce = {}

const config = {
	// 示例
	// wxLogin : {url : '/api/wxLogin', method : 'POST', 
	// auth : false, showLoading : true, loadingTitle : '加载中...',
	// limit : 1000
	// },

	getConfig: {
		url: '/api/getConfig',
		method: 'GET'
	},

	// banner列表
	bannerList: {
		url: '/banner/list',
		method: 'GET',
		showLoading : true,
	},

	// 公告列表
	noticeList: {
		url: '/notice/list',
		method: 'GET',
		showLoading : true,
	},
	// 公告详情
	noticeOne: {
		url: '/notice/one',
		method: 'GET',
		showLoading : true,
	},
	

	// 商品列表
	goodsPage: {
		url: '/goods/page',
		method: 'GET',
		showLoading : true,
	},
	// 商品详情
	goodsOne: {
		url: '/goods/one',
		method: 'GET',
		showLoading : true,
	},
	// 购物车分页
	cartPage: {
		url: '/goods/shopping/cart/page',
		method: 'GET',
		showLoading : true,
		auth : true,
	},
	// 加入购物车
	cartAdd: {
		url: '/goods/join/shopping/cart',
		method: 'POST',
		showLoading : true,
		auth : true,
	},
	// 删除购物车
	cartDel: {
		url: '/goods/shopping/cart/delete',
		method: 'POST',
		showLoading : true,
		auth : true,
	},
	// 修改购物车数量
	cartNum: {
		url: '/goods/shopping/cart/add/or/delete',
		method: 'POST',
		auth : true,
		debounce : 1000,
	},
	
	

	//分类列表
	categoryList: {
		url: '/category/list',
		method: 'GET',
		showLoading : true,
	},

	//新增地址
	addressAdd: {
		url: '/address/add',
		method: 'POST',
		limit: 500,
		auth : true,
		showLoading : true,
	},
	//修改默认地址
	addressDefault: {
		url: '/address/default',
		method: 'POST',
		auth : true,
		showLoading : true,
	},
	//删除地址
	addressDelete: {
		url: '/address/delete',
		method: 'POST',
		auth : true,
		showLoading : true,
	},
	//修改地址
	addressEdit: {
		url: '/address/edit',
		method: 'POST',
		limit: 500,
		auth : true,
		showLoading : true,
	},
	//分页查询地址
	addressPage: {
		url: '/address/page',
		method: 'GET',
		auth : true,
		showLoading : true,
	},
	// 分页查询我的客户
	getMyUserPage: {
		url: '/shop/user',
		method: 'GET',
		auth : true,
		showLoading : true,
	},
	
	
	//分页查询订单
	orderPage: {
		url: '/order/page',
		method: 'GET',
		auth : true,
		showLoading : true,
	},
	//查询订单详情
	orderOne: {
		url: '/order/one',
		method: 'GET',
		auth : true,
		showLoading : true,
	},
	
	
	// 微信登录接口
	wxLogin: {
		url: '/login/login',
		method: 'POST', 
		limit : 500,
		showLoading : true,
	},
	
	// 修改个人信息接口
	updateInfo: {
		url: '/user/edit',
		method: 'POST',
		auth: true, 
		limit : 500,
		showLoading : true,
	},
	// 获取用户信息
	getInfo: {
		url: '/user/info',
		method: 'GET',
		auth: true, 
		showLoading : true,
	},
	
	
	// 获取我的租赁
	getLeasePage: {
		url: '/user/lease/page',
		method: 'POST',
		showLoading : true,
	},
	// 申请成为水洗店
	applyShopHotel: {
		url: '/shop/apply',
		method: 'POST',
		showLoading : true,
		auth : true,
	},
	// 店铺申请提现
	storeWithdrawalApplication: {
		url: '/shop/withdrawal/apply',
		method: 'POST',
		showLoading : true,
		auth : true,
	},
	// 提现日志
	withdrawalLog: {
		url: '/withdrawal/page',
		method: 'GET',
		showLoading : true,
		auth : true,
	},
	// 水洗店首页数据
	laundryStoreHomeData: {
		url: '/shop/index',
		method: 'GET',
		// showLoading : true,
		auth : true,
	},
	

}



export function api(key, data, callback, loadingTitle) {
	let req = config[key]

	if (!req) {
		console.error('无效key' + key);
		return
	}

	if (typeof callback == 'string') {
		loadingTitle = callback
	}

	if (typeof data == 'function') {
		callback = data
		data = {}
	}

	// 接口限流
	if (req.limit) {
		let storageKey = req.url
		let storage = limit[storageKey]
		if (storage && new Date().getTime() - storage < req.limit) {
			return
		}
		limit[storageKey] = new Date().getTime()
	}

	//必须登录
	if (req.auth) {
		if (!uni.getStorageSync('token')) {
			uni.navigateTo({
				url: '/pages_order/auth/wxLogin'
			})
			console.error('需要登录')
			return
		}
	}
	
	// 接口防抖
	if(req.debounce){
		
		let storageKey = req.url
		let storage = debounce[storageKey]
		
		if (storage) {
			clearTimeout(storage)
		}
		
		debounce[storageKey] = setTimeout(() => {
			
			clearTimeout(storage)
			
			delete debounce[storageKey]
			
			http.http(req.url, data, callback, req.method,
				loadingTitle || req.showLoading, loadingTitle || req.loadingTitle)
		}, req.debounce)
		
		return
	}

	http.http(req.url, data, callback, req.method,
		loadingTitle || req.showLoading, loadingTitle || req.loadingTitle)
}



export default api